@@ -98,6 +98,7 @@ def tidy_all_the_variables(host):
     _vars[host] = host.vars.copy()
     for group in host.get_groups():
         remove_inherited_and_overridden_vars(_vars[host], group)
+        remove_inherited_and_overridden_group_vars(group)
     return _vars
 
 
@@ -105,7 +106,8 @@ def generate_graph_for_host(host):
     # dedup graph edges
     edges = set(parent_graphs(host, host.groups))
     vars = tidy_all_the_variables(host)
-    nodes = {Node(host.name, vars=vars[host], leaf=True)}
+    nodes = set()
+    nodes.add(Node(host.name, vars=vars[host], leaf=True))
 
     for group in host.get_groups():
         nodes.add(Node(group.name, vars=vars[group]))
